@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::PluginBundle::Author::RTHOMPSON;
 # ABSTRACT: RTHOMPSON's Dist::Zilla Configuration
-$Dist::Zilla::PluginBundle::Author::RTHOMPSON::VERSION = '0.142221';
+$Dist::Zilla::PluginBundle::Author::RTHOMPSON::VERSION = '0.160500';
 use Moose;
 use Carp;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -116,6 +116,7 @@ sub configure {
         'PruneCruft',
         'ManifestSkip',
         'MetaYAML',
+        'MetaJSON',
         [ 'MetaNoIndex' => { dir => 'corpus' } ],
         'License',
         'ExecDir',
@@ -230,7 +231,7 @@ Dist::Zilla::PluginBundle::Author::RTHOMPSON - RTHOMPSON's Dist::Zilla Configura
 
 =head1 VERSION
 
-version 0.142221
+version 0.160500
 
 =head1 SYNOPSIS
 
@@ -248,6 +249,7 @@ This plugin bundle, in its default configuration, is equivalent to:
     [PruneCruft]
     [ManifestSkip]
     [MetaYAML]
+    [MetaJSON]
     [MetaNoIndex]
     dir = corpus
     [License]
